@@ -6,14 +6,13 @@ import (
 )
 
 type Addition struct {
-	Username       string `json:"username" required:"true"`
-	Password       string `json:"password" required:"true"`
+	Username string `json:"username" required:"true"`
+	Password string `json:"password" required:"true"`
+	driver.RootID
 	OrderBy        string `json:"order_by" type:"select" options:"file_name,size,update_at" default:"file_name"`
 	OrderDirection string `json:"order_direction" type:"select" options:"asc,desc" default:"asc"`
-	driver.RootID
-	// define other
-	StreamUpload bool `json:"stream_upload"`
-	//Field string `json:"field" type:"select" required:"true" options:"a,b,c" default:"a"`
+	StreamUpload   bool   `json:"stream_upload"`
+	AccessToken    string
 }
 
 var config = driver.Config{
