@@ -33,7 +33,7 @@ var config = driver.Config{
 func init() {
 	op.RegisterDriver(func() driver.Driver {
 		return &AliyundriveOpen{
-			base: "https://open.aliyundrive.com",
+			base: "https://openapi.aliyundrive.com",
 		}
 	})
 }
