@@ -28,7 +28,7 @@ func WalkFS(ctx context.Context, depth int, name string, info model.Obj, walkFn
 	}
 	meta, _ := op.GetNearestMeta(name)
 	// Read directory names.
-	objs, err := List(context.WithValue(ctx, "meta", meta), name)
+	objs, err := List(context.WithValue(ctx, "meta", meta), name, &ListArgs{})
 	if err != nil {
 		return walkFnErr
 	}
